#undef PACKAGE
#undef VERSION

#undef GETTEXT_PACKAGE

#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef PACKAGE_LOCALE_DIR
#undef PACKAGE_DATA_DIR
#undef PACKAGE_SOURCE_DIR
#undef LOCALEDIR

#undef HAVE_LIBGTOP
#undef LIBGTOP_MAJOR_VERSION
#undef LIBGTOP_MINOR_VERSION
#undef LIBGTOP_MICRO_VERSION
#undef LIBGTOP_SERVER_VERSION
#undef LIBGTOP_VERSION
#undef LIBGTOP_VERSION_CODE
#undef int64_t
#undef u_int64_t
#undef u_int32_t
#undef u_int16_t
#undef u_int8_t

#undef RIPPLES

#undef ENABLE_PROFILING

#undef HAVE_CHANGE_PIXEL_SIZE
